<?php
/**
 * @package   Essentials YOOtheme Pro 2.2.10 build 0508.0933
 * @author    ZOOlanders https://www.zoolanders.com
 * @copyright Copyright (C) Joolanders, SL
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 */

namespace ZOOlanders\YOOessentials\Auth\Listener;

use YOOtheme\Event;
use ZOOlanders\YOOessentials\Config;
use ZOOlanders\YOOessentials\Auth\Auth;
use ZOOlanders\YOOessentials\Auth\AuthManager;

class LoadAuths
{
    public Config $config;
    public AuthManager $manager;

    public function __construct(Config $config, AuthManager $manager)
    {
        $this->config = $config;
        $this->manager = $manager;
    }

    public function handle(): void
    {
        $key = AuthManager::AUTHS_CONFIG_KEY;

        try {
            $auths = $this->manager->createAuths($this->config->get($key, []));

            $auths = array_map(function (Auth $auth) {
                return $auth->withDecryptedKeys()->toArray();
            }, $auths);

            $this->config->set($key, $auths);
        } catch (\Exception $e) {
            Event::emit('yooessentials.error', [
                'addon' => 'auth',
                'task' => 'load-config',
                'error' => $e->getMessage(),
            ]);
        }
    }
}
