<?php
/**
 * @package   Essentials YOOtheme Pro 2.2.10 build 0508.0933
 * @author    ZOOlanders https://www.zoolanders.com
 * @copyright Copyright (C) Joolanders, SL
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 */

namespace ZOOlanders\YOOessentials\Form\Action\AcyMailing;

use YOOtheme\Http\Response;
use ZOOlanders\YOOessentials\Api\AcyMailing\AcyMailingApiInterface;

class AcyMailingController
{
    public const LISTS_ENDPOINT = 'yooessentials/form/actions/acymailing/lists';
    public const CUSTOM_FIELDS_ENDPOINT = 'yooessentials/form/actions/acymailing/custom-fields';

    public function listsField(AcyMailingApiInterface $acyMailing, Response $response): Response
    {
        try {
            $lists = $acyMailing->getLists();

            $items = array_values(array_map(function ($list) {
                return [
                    'value' => $list->id,
                    'text' => $list->name,
                ];
            }, $lists));

            $fields = [
                'lists' => [
                    'type' => 'select',
                    'label' => 'Lists',
                    'description' => 'The lists to which to subscribe.',
                    'options' => $items,
                    'source' => true,
                    'attrs' => [
                        'multiple' => true,
                    ],
                ],
            ];
        } catch (\Exception $e) {
            return $response->withJson($e->getMessage(), 400);
        }

        return $response->withJson($fields);
    }

    public function customFields(AcyMailingApiInterface $acyMailing, Response $response): Response
    {
        try {
            $fields = array_map(fn ($field) => [
                'id' => $field->id,
                'title' => $field->name . ($field->required ? ' *' : ''),
                'type' => $field->type,
                'meta' => ['type' => $field->type]
            ], array_values($acyMailing->getCustomFields()));
        } catch (\Exception $e) {
            return $response->withJson($e->getMessage(), 400);
        }

        return $response->withJson($fields);
    }
}
