<?php
/**
 * @package   Essentials YOOtheme Pro 2.2.10 build 0508.0933
 * @author    ZOOlanders https://www.zoolanders.com
 * @copyright Copyright (C) Joolanders, SL
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 */

namespace ZOOlanders\YOOessentials\Form;

use YOOtheme\Application;
use YOOtheme\Builder;
use YOOtheme\Path;
use YOOtheme\View;
use ZOOlanders\YOOessentials\UpdateTransform;

require_once __DIR__ . '/class_aliases.php';

return [
    'routes' => [
        ['get', Action\ActionController::ACTIONS_URL, Action\ActionController::class . '@actions', ['allowed' => true]],
        ['post', Http\FormSubmissionRequest::SUBMIT_URL, Controller\FormController::class . '@submit', ['allowed' => true]],
        [
            'post',
            Controller\FormAdminController::FIELDS_URL,
            Controller\FormAdminController::class . '@fields',
            ['allowed' => true],
        ],
    ],

    'events' => [
        Http\FormSubmissionRequest::SUBMISSION_EVENT => [
            Action\ActionListener::class => ['handleFormActions', -10],
        ],

        'source.init' => [
            Listener\AddFormSource::class => ['@handle', 66],
        ],

        'customizer.init' => [
            Action\ActionListener::class => ['initCustomizer', 5],
            Listener\LoadCustomizerData::class => ['@handle', 10],
        ],

        'builder.type' => [
            Listener\AddFormPanel::class => ['@handle', -10],
        ],
    ],

    'extend' => [
        Builder::class => function (Builder $builder, $app) {
            /** @var Application $app */
            $builder->addTypePath(Path::get('./elements/*/element.json'));

            $formIdTransform = $app(FormIdTransform::class);

            $builder->addTransform('presave', [$formIdTransform, 'presave']);
            $builder->addTransform('preload', [$formIdTransform, 'preload']);
            $builder->addTransform('render', new ControlTransform());
            $builder->addTransform('render', new FormTransform($builder, $app(FormConfigRepository::class)));
        },

        View::class => function (View $view) {
            $view->addHelper(Html\HtmlHelper::class);
        },

        UpdateTransform::class => function (UpdateTransform $update) {
            $update->addGlobals(require __DIR__ . '/updates.php');
        },
    ],

    'services' => [
        FormService::class => '',
        FormConfigRepository::class => '',
        Action\ActionManager::class => '',
        Http\FormSubmissionRequest::class => '',
    ],

    'loaders' => [
        'yooessentials-form-actions' => new Action\ActionLoader(),
    ],

    'yooessentials-bootstrap' => [
        __DIR__ . '/actions/AcyMailing/bootstrap.php',
        __DIR__ . '/actions/Airtable/bootstrap.php',
        __DIR__ . '/actions/Data/bootstrap.php',
        __DIR__ . '/actions/Email/bootstrap.php',
        __DIR__ . '/actions/Message/bootstrap.php',
        __DIR__ . '/actions/Download/bootstrap.php',
        __DIR__ . '/actions/Redirect/bootstrap.php',
        __DIR__ . '/actions/Validate/bootstrap.php',
        __DIR__ . '/actions/Mailchimp/bootstrap.php',
        __DIR__ . '/actions/SaveCsv/bootstrap.php',
        __DIR__ . '/actions/SaveDatabase/bootstrap.php',
        __DIR__ . '/actions/SaveGoogleSheet/bootstrap.php',
    ],
];
