<?php
/**
 * @package   Essentials YOOtheme Pro 2.2.10 build 0508.0933
 * @author    ZOOlanders https://www.zoolanders.com
 * @copyright Copyright (C) Joolanders, SL
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 */

namespace ZOOlanders\YOOessentials\Source\Provider\CloudflareStream\Type;

use ZOOlanders\YOOessentials\Source\GraphQL\AbstractQueryType;
use ZOOlanders\YOOessentials\Source\GraphQL\HasSourceInterface;
use ZOOlanders\YOOessentials\Source\Resolver\CachesResolvedSourceData;
use ZOOlanders\YOOessentials\Source\Resolver\LoadsSourceFromArgs;
use ZOOlanders\YOOessentials\Source\Provider\CloudflareStream\CloudflareStreamSource;

class CloudlfareStreamVideoQueryType extends AbstractQueryType implements HasSourceInterface
{
    use LoadsSourceFromArgs, CachesResolvedSourceData;

    public function name(): string
    {
        return "cloudflareStreamVideo_{$this->source()->id()}_query";
    }

    public function label(): string
    {
        return "{$this->source()->name()} Video";
    }

    public static function getCacheKey(): string
    {
        return 'cloudflare-stream-video';
    }

    public function config(): array
    {
        return [
            'fields' => [
                $this->name() => [
                    'type' => CloudflareStreamVideoType::TYPE_NAME,

                    'args' => [
                        'uid' => [
                            'type' => 'String',
                        ],
                        'cache' => [
                            'type' => 'Int',
                        ],
                    ],

                    'metadata' => [
                        'group' => 'Cloudflare Stream',
                        'label' => $this->label(),
                        'fields' => [
                            'uid' => [
                                'label' => 'Video',
                                'description' => 'Select the video to create the source from.',
                                'type' => 'yooessentials-cloudflare-stream',
                                'sourceId' => $this->source()->id(),
                            ],

                            'cache' => $this->cacheField(),
                        ],
                    ],

                    'extensions' => [
                        'call' => [
                            'func' => __CLASS__ . '::resolve',
                            'args' => [
                                'source_id' => $this->source()->id(),
                            ],
                        ],
                    ],
                ],
            ],
        ];
    }

    public static function resolve($root, array $args)
    {
        /** @var CloudflareStreamSource */
        $source = self::loadSource($args, CloudflareStreamSource::class);

        $uid = $args['uid'] ?? null;

        if (!$source || !$uid) {
            return [];
        }

        $stream = self::resolveFromCache($source, $args, function () use ($source, $args) {
            return $source->api()->stream($args['uid']);
        });

        $source->signStream($stream);

        return $stream;
    }
}
