<?php
/**
 * @package   Essentials YOOtheme Pro 2.2.10 build 0508.0933
 * @author    ZOOlanders https://www.zoolanders.com
 * @copyright Copyright (C) Joolanders, SL
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 */

namespace ZOOlanders\YOOessentials\Source\Provider\GoogleBusinessProfile\Type;

use ZOOlanders\YOOessentials\Source\GraphQL\AbstractQueryType;
use ZOOlanders\YOOessentials\Source\GraphQL\HasSourceInterface;
use ZOOlanders\YOOessentials\Source\Resolver\CachesResolvedSourceData;
use ZOOlanders\YOOessentials\Source\Resolver\LoadsSourceFromArgs;
use ZOOlanders\YOOessentials\Source\Provider\GoogleBusinessProfile\GoogleBusinessProfileSource;

class GoogleBusinessProfileLocationQuery extends AbstractQueryType implements HasSourceInterface
{
    use CachesResolvedSourceData, LoadsSourceFromArgs;

    public function name(): string
    {
        $id = $this->source()->id();

        return "googleMyBusinessLocation_{$id}_query";
    }

    public function label(): string
    {
        return "{$this->source()->name()} Location";
    }

    public static function getCacheKey(): string
    {
        return 'google-business-profile-location';
    }

    public function config(): array
    {
        return [
            'fields' => [
                $this->name() => [
                    'type' => GoogleBusinessProfileLocationType::TYPE_NAME,

                    'args' => [
                        'cache' => [
                            'type' => 'Int',
                        ],
                    ],

                    'metadata' => [
                        'group' => 'Google Business Profile',
                        'label' => $this->label(),
                        'fields' => [
                            'cache' => $this->cacheField(),
                        ],
                    ],

                    'extensions' => [
                        'call' => [
                            'func' => static::class . '::resolve',
                            'args' => [
                                'source_id' => $this->source->id(),
                            ],
                        ],
                    ],
                ],
            ],
        ];
    }

    public static function resolve($root, array $args): array
    {
        /** @var GoogleBusinessProfileSource */
        $source = self::loadSource($args, GoogleBusinessProfileSource::class);

        if (!$source || !$source->location) {
            return [];
        }

        return self::resolveFromCache($source, $args, function () use ($source) {
            $location = $source->api()->location($source->location);
            $reviews = $source->api()->reviews($source->businessAccount, $source->location);

            $location['totalReviewCount'] = $reviews['totalReviewCount'] ?? 0;
            $location['averageRating'] = $reviews['averageRating'] ?? 0;

            return $location;
        });
    }
}
