<?php
/**
 * @package   Essentials YOOtheme Pro 2.2.10 build 0508.0933
 * @author    ZOOlanders https://www.zoolanders.com
 * @copyright Copyright (C) Joolanders, SL
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 */

namespace ZOOlanders\YOOessentials\Source\Provider\GooglePhotos\Type;

use ZOOlanders\YOOessentials\Source\GraphQL\AbstractQueryType;
use ZOOlanders\YOOessentials\Source\GraphQL\HasSourceInterface;
use ZOOlanders\YOOessentials\Source\Resolver\CachesResolvedSourceData;
use ZOOlanders\YOOessentials\Source\Resolver\LoadsSourceFromArgs;
use ZOOlanders\YOOessentials\Source\Provider\GooglePhotos\GooglePhotosSource;

class GooglePhotosAlbumQueryType extends AbstractQueryType implements HasSourceInterface
{
    use LoadsSourceFromArgs, CachesResolvedSourceData;

    public function name(): string
    {
        return "googlePhotosAlbum_{$this->source()->id()}_query";
    }

    public function label(): string
    {
        return "{$this->source()->name()} Album";
    }

    public static function getCacheKey(): string
    {
        return 'google-photos-album';
    }

    public function config(): array
    {
        return [
            'fields' => [
                $this->name() => [
                    'type' => GooglePhotosAlbumType::TYPE_NAME,

                    'args' => [
                        'albumId' => [
                            'type' => 'String',
                        ],
                        'cache' => [
                            'type' => 'Int',
                        ],
                    ],

                    'metadata' => [
                        'group' => 'Google Photos',
                        'label' => $this->label(),
                        'fields' => [
                            'albumId' => [
                                'label' => 'Album',
                                'type' => 'yooessentials-select-dropdown-async',
                                'description' => 'The Album which data to query.',
                                'endpoint' => 'yooessentials/source/google/photos/albums',
                                'meta' => false,
                                'source' => true,
                                'params' => [
                                    'source_id' => $this->source->id(),
                                ],
                            ],
                            'cache' => $this->cacheField(),
                        ],
                    ],

                    'extensions' => [
                        'call' => [
                            'func' => __CLASS__ . '::resolve',
                            'args' => [
                                'source_id' => $this->source->id(),
                            ],
                        ],
                    ],
                ],
            ],
        ];
    }

    public static function resolve($root, array $args)
    {
        $source = self::loadSource($args, GooglePhotosSource::class);
        $albumId = $args['albumId'] ?? '';

        if (!$source || empty($albumId)) {
            return [];
        }

        return self::resolveFromCache($source, $args, function () use ($source, $albumId) {
            return (array) $source->api()->album($albumId);
        });
    }
}
