<?php
/**
 * @package   Essentials YOOtheme Pro 2.2.10 build 0508.0933
 * @author    ZOOlanders https://www.zoolanders.com
 * @copyright Copyright (C) Joolanders, SL
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 */

namespace ZOOlanders\YOOessentials\Source\Provider\Twitter\Type;

use ZOOlanders\YOOessentials\Source\GraphQL\AbstractQueryType;
use ZOOlanders\YOOessentials\Source\GraphQL\HasSourceInterface;
use ZOOlanders\YOOessentials\Source\Resolver\CachesResolvedSourceData;
use ZOOlanders\YOOessentials\Source\Resolver\LoadsSourceFromArgs;
use ZOOlanders\YOOessentials\Source\Provider\Twitter\TwitterSource;

class TwitterMyTweetsQueryType extends AbstractQueryType implements HasSourceInterface
{
    use LoadsSourceFromArgs, CachesResolvedSourceData;

    public function name(): string
    {
        $id = $this->source()->id();

        return "twitter_{$id}_tweets_query";
    }

    public function label(): string
    {
        return "{$this->source()->name()} My Tweets";
    }

    public static function getCacheKey(): string
    {
        return 'twitter-my-tweets';
    }

    public function config(): array
    {
        return [
            'fields' => [
                $this->name() => [
                    'type' => [
                        'listOf' => TwitterTweetType::TYPE_NAME,
                    ],

                    'args' => [
                        'start_time' => [
                            'type' => 'String',
                        ],

                        'end_time' => [
                            'type' => 'String',
                        ],

                        'limit' => [
                            'type' => 'Int',
                        ],

                        'cache' => [
                            'type' => 'Int',
                        ],
                    ],

                    'metadata' => [
                        'group' => 'Twitter',
                        'label' => $this->label(),
                        'fields' => [
                            '_datetime_filter' => [
                                'type' => 'grid',
                                'description' => 'Restrict the tweets by it start and/or end datetime.',
                                'width' => '1-2',
                                'fields' => [
                                    'start_time' => [
                                        'label' => 'Since',
                                        'type' => 'yooessentials-datetime',
                                        'source' => true,
                                        'small' => true,
                                        'valueFormat' => 'yyyy-MM-dd HH:mm',
                                        'displayFormat' => 'yyyy-MM-dd HH:mm',
                                    ],

                                    'end_time' => [
                                        'label' => 'Until',
                                        'type' => 'yooessentials-datetime',
                                        'source' => true,
                                        'small' => true,
                                        'valueFormat' => 'yyyy-MM-dd HH:mm',
                                        'displayFormat' => 'yyyy-MM-dd HH:mm',
                                    ],
                                ],
                            ],

                            'limit' => [
                                'label' => 'Limit',
                                'type' => 'yooessentials-number',
                                'description' => 'The maximum amount of tweets to fetch.',
                                'default' => TwitterSource::TWEETS_DEFAULT_LIMIT,
                                'source' => true,
                            ],

                            'cache' => $this->cacheField(),
                        ],
                    ],

                    'extensions' => [
                        'call' => [
                            'func' => __CLASS__ . '::resolve',
                            'args' => [
                                'source_id' => $this->source->id(),
                            ],
                        ],
                    ],
                ],
            ],
        ];
    }

    public static function resolve($root, array $args): array
    {
        /** @var TwitterSource */
        $source = self::loadSource($args, TwitterSource::class);

        if (!$source) {
            return [];
        }

        foreach (['start_time', 'end_time'] as $field) {
            if (isset($args[$field])) {
                $args[$field] = \DateTime::createFromFormat('Y-m-d H:i', $args[$field])->format(DATE_ATOM);
            }
        }

        return self::resolveFromCache($source, $args, function () use ($source, $args) {
            return $source->api()->tweets($source->api()->account()['id'], $args['limit'] ?? null, $args);
        });
    }
}
