<?php
/**
 * @package   Essentials YOOtheme Pro 2.2.10 build 0508.0933
 * @author    ZOOlanders https://www.zoolanders.com
 * @copyright Copyright (C) Joolanders, SL
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 */

namespace ZOOlanders\YOOessentials\Source\Provider\Twitter\Type;

use ZOOlanders\YOOessentials\Source\GraphQL\TypeInterface;
use ZOOlanders\YOOessentials\Util;

class TwitterUserType implements TypeInterface
{
    public const TYPE_NAME = 'TwitterUser';
    public const TYPE_LABEL = 'Twitter User';

    public function type(): string
    {
        return TypeInterface::TYPE_OBJECT;
    }

    public function name(): string
    {
        return self::TYPE_NAME;
    }

    public function label(): string
    {
        return self::TYPE_LABEL;
    }

    public function config(): array
    {
        return [
            'fields' => [
                'id' => [
                    'type' => 'String',
                    'metadata' => [
                        'label' => 'ID',
                    ],
                ],
                'username' => [
                    'type' => 'String',
                    'metadata' => [
                        'label' => 'Username',
                    ],
                ],
                'created_at' => [
                    'type' => 'String',
                    'metadata' => [
                        'label' => 'Created At',
                        'filters' => ['date'],
                    ],
                ],
                'url' => [
                    'type' => 'String',
                    'metadata' => [
                        'label' => 'Profile URL',
                    ],
                ],
                'name' => [
                    'type' => 'String',
                    'metadata' => [
                        'label' => 'Profile Name',
                    ],
                ],
                'profile_image' => [
                    'type' => 'String',
                    'metadata' => [
                        'label' => 'Profile Image',
                    ],
                    'extensions' => [
                        'call' => __CLASS__ . '::profileImage',
                    ],
                ],
                'description' => [
                    'type' => 'String',
                    'metadata' => [
                        'label' => 'Profile Description',
                        'filters' => ['limit'],
                    ],
                ],
                'followers_count' => [
                    'type' => 'Int',
                    'metadata' => [
                        'label' => 'Total Followers',
                    ],
                    'extensions' => [
                        'call' => __CLASS__ . '::followers_count',
                    ],
                ],
                'following_count' => [
                    'type' => 'Int',
                    'metadata' => [
                        'label' => 'Total Following',
                    ],
                    'extensions' => [
                        'call' => __CLASS__ . '::following_count',
                    ],
                ],
                'tweet_count' => [
                    'type' => 'Int',
                    'metadata' => [
                        'label' => 'Total Tweets',
                    ],
                    'extensions' => [
                        'call' => __CLASS__ . '::tweet_count',
                    ],
                ],
                'listed_count' => [
                    'type' => 'Int',
                    'metadata' => [
                        'label' => 'Total Listed',
                    ],
                    'extensions' => [
                        'call' => __CLASS__ . '::listed_count',
                    ],
                ],
            ],

            'metadata' => [
                'type' => true,
                'label' => $this->label(),
            ],
        ];
    }

    public static function followers_count($user): int
    {
        return $user['public_metrics']['followers_count'] ?? 0;
    }

    public static function following_count($user): int
    {
        return $user['public_metrics']['following_count'] ?? 0;
    }

    public static function tweet_count($user): int
    {
        return $user['public_metrics']['tweet_count'] ?? 0;
    }

    public static function listed_count($user): int
    {
        return $user['public_metrics']['listed_count'] ?? 0;
    }

    public static function profileImage($user)
    {
        $id = $user['id'] ?? '';
        $url = $user['profile_image_url'] ?? '';

        return Util\File::cacheMedia($url, "twitter-user-$id");
    }
}
