<?php

namespace ZOOlanders\YOOessentials\Vendor\AsyncAws\Core\Sts\ValueObject;

use ZOOlanders\YOOessentials\Vendor\AsyncAws\Core\Exception\InvalidArgument;
/**
 * You can pass custom key-value pair attributes when you assume a role or federate a user. These are called session
 * tags. You can then use the session tags to control access to resources. For more information, see Tagging Amazon Web
 * Services STS Sessions in the *IAM User Guide*.
 *
 * @see https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html
 */
final class Tag
{
    /**
     * The key for a session tag.
     */
    private $key;
    /**
     * The value for a session tag.
     */
    private $value;
    /**
     * @param array{
     *   Key: string,
     *   Value: string,
     * } $input
     */
    public function __construct(array $input)
    {
        $this->key = $input['Key'] ?? null;
        $this->value = $input['Value'] ?? null;
    }
    public static function create($input) : self
    {
        return $input instanceof self ? $input : new self($input);
    }
    public function getKey() : string
    {
        return $this->key;
    }
    public function getValue() : string
    {
        return $this->value;
    }
    /**
     * @internal
     */
    public function requestBody() : array
    {
        $payload = [];
        if (null === ($v = $this->key)) {
            throw new InvalidArgument(\sprintf('Missing parameter "Key" for "%s". The value cannot be null.', __CLASS__));
        }
        $payload['Key'] = $v;
        if (null === ($v = $this->value)) {
            throw new InvalidArgument(\sprintf('Missing parameter "Value" for "%s". The value cannot be null.', __CLASS__));
        }
        $payload['Value'] = $v;
        return $payload;
    }
}
