<?php

namespace ZOOlanders\YOOessentials\Vendor\AsyncAws\S3\Result;

use ZOOlanders\YOOessentials\Vendor\AsyncAws\Core\Response;
use ZOOlanders\YOOessentials\Vendor\AsyncAws\Core\Result;
use ZOOlanders\YOOessentials\Vendor\AsyncAws\S3\Enum\RequestCharged;
class DeleteObjectOutput extends Result
{
    /**
     * Specifies whether the versioned object that was permanently deleted was (true) or was not (false) a delete marker.
     */
    private $deleteMarker;
    /**
     * Returns the version ID of the delete marker created as a result of the DELETE operation.
     */
    private $versionId;
    private $requestCharged;
    public function getDeleteMarker() : ?bool
    {
        $this->initialize();
        return $this->deleteMarker;
    }
    /**
     * @return RequestCharged::*|null
     */
    public function getRequestCharged() : ?string
    {
        $this->initialize();
        return $this->requestCharged;
    }
    public function getVersionId() : ?string
    {
        $this->initialize();
        return $this->versionId;
    }
    protected function populateResult(Response $response) : void
    {
        $headers = $response->getHeaders();
        $this->deleteMarker = isset($headers['x-amz-delete-marker'][0]) ? \filter_var($headers['x-amz-delete-marker'][0], \FILTER_VALIDATE_BOOLEAN) : null;
        $this->versionId = $headers['x-amz-version-id'][0] ?? null;
        $this->requestCharged = $headers['x-amz-request-charged'][0] ?? null;
    }
}
