<?php

declare (strict_types=1);
/*
 * This file is part of the league/commonmark package.
 *
 * (c) Colin O'Dell <colinodell@gmail.com>
 *
 * Original code based on the CommonMark JS reference parser (https://bitly.com/commonmark-js)
 *  - (c) John MacFarlane
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace ZOOlanders\YOOessentials\Vendor\League\CommonMark\Extension\CommonMark\Renderer\Block;

use ZOOlanders\YOOessentials\Vendor\League\CommonMark\Extension\CommonMark\Node\Block\Heading;
use ZOOlanders\YOOessentials\Vendor\League\CommonMark\Node\Node;
use ZOOlanders\YOOessentials\Vendor\League\CommonMark\Renderer\ChildNodeRendererInterface;
use ZOOlanders\YOOessentials\Vendor\League\CommonMark\Renderer\NodeRendererInterface;
use ZOOlanders\YOOessentials\Vendor\League\CommonMark\Util\HtmlElement;
use ZOOlanders\YOOessentials\Vendor\League\CommonMark\Xml\XmlNodeRendererInterface;
final class HeadingRenderer implements NodeRendererInterface, XmlNodeRendererInterface
{
    /**
     * @param Heading $node
     *
     * {@inheritDoc}
     *
     * @psalm-suppress MoreSpecificImplementedParamType
     */
    public function render(Node $node, ChildNodeRendererInterface $childRenderer) : \Stringable
    {
        Heading::assertInstanceOf($node);
        $tag = 'h' . $node->getLevel();
        $attrs = $node->data->get('attributes');
        return new HtmlElement($tag, $attrs, $childRenderer->renderNodes($node->children()));
    }
    public function getXmlTagName(Node $node) : string
    {
        return 'heading';
    }
    /**
     * @param Heading $node
     *
     * @return array<string, scalar>
     *
     * @psalm-suppress MoreSpecificImplementedParamType
     */
    public function getXmlAttributes(Node $node) : array
    {
        Heading::assertInstanceOf($node);
        return ['level' => $node->getLevel()];
    }
}
